@@ -137,6 +137,7 @@ MaestroPipelineList <- R6::R6Class(
     #' @return list
     get_errors = function() {
       purrr::map(self$MaestroPipelines, ~.x$get_errors()) |>
+        purrr::set_names(self$get_pipe_names()) |> 
         purrr::discard(is.null)
     },
 
@@ -145,6 +146,7 @@ MaestroPipelineList <- R6::R6Class(
     #' @return list
     get_warnings = function() {
       purrr::map(self$MaestroPipelines, ~.x$get_warnings()) |>
+        purrr::set_names(self$get_pipe_names()) |> 
         purrr::discard(is.null)
     },
 
@@ -153,6 +155,7 @@ MaestroPipelineList <- R6::R6Class(
     #' @return list
     get_messages = function() {
       purrr::map(self$MaestroPipelines, ~.x$get_messages()) |>
+        purrr::set_names(self$get_pipe_names()) |> 
         purrr::discard(is.null)
     },
 
@@ -345,7 +348,7 @@ MaestroPipelineList <- R6::R6Class(
         do.call(pipe$run, append(dots, list(.input = .input, ...)))
         .input <- pipe$get_artifacts()
         out_names <- network$to[network$from == pipe$get_pipe_name()]
-        if (pipe$get_status_chr() == "Error") return(invisible())
+        if (pipe$get_status_chr() %in% c("Error", "Not Run")) return(invisible())
         if (length(out_names) == 0) return(invisible())
         for (i in out_names) {
           pipe <- self$get_pipe_by_name(i)
